@@ -226,12 +226,9 @@ class asm(Unit):
                     yield pprint(F'{function.name}:')
                     break
             for insn in bb.block:
-                try:
-                    hd = one(hexdump(insn.bytes, metrics_opc))
-                except LookupError:
-                    hd = 'wat: {}'.format(insn.bytes.hex())
+                hd = one(hexdump(insn.bytes, metrics_opc))
                 msg = F'  {insn.mnemonic:<{memo_width}} {insn.op_str:<{args_width}}'
                 if not no_hexdump:
                     msg = F'{msg}  ; {hd}'
-                yield pprint(msg)
+                yield pprint(msg, insn.address)
             tail = address + bb.size
