@@ -5,11 +5,11 @@ import textwrap
 import codecs
 import string
 
-from . import arg, HexViewer
-from ...lib.meta import metavars, CustomStringRepresentation, SizeInt
-from ...lib.types import INF
-from ...lib.tools import isbuffer, lookahead
-from ...lib.patterns import formats
+from refinery.units.sinks import arg, HexViewer
+from refinery.lib.meta import metavars, CustomStringRepresentation, SizeInt
+from refinery.lib.types import INF
+from refinery.lib.tools import isbuffer, lookahead
+from refinery.lib.patterns import formats
 
 
 class peek(HexViewer):
@@ -88,10 +88,10 @@ class peek(HexViewer):
         remaining = linecount
         result = []
         if codec is None:
-            from ..encoding.esc import esc
+            from refinery.units.encoding.esc import esc
             decoded = data[:abs(width * linecount)]
             decoded = str(decoded | -esc(bare=True))
-            for k in range(0, abs(linecount), width):
+            for k in range(0, abs(linecount) * width, width):
                 result.append(decoded[k:k + width])
             return result
         try:
@@ -151,8 +151,13 @@ class peek(HexViewer):
                 padding += 6
 
         metrics = self._get_metrics(len(data), self.args.lines, padding)
+
+        if self.args.brief:
+            metrics.address_width = 0
+            metrics.fit_to_width(allow_increase=True)
+
         sepsize = metrics.hexdump_width
-        txtsize = self.args.width or sepsize
+        txtsize = self.args.width or (sepsize - metrics.padding)
 
         if self.args.lines and data:
             if self.args.esc:
@@ -207,6 +212,12 @@ class peek(HexViewer):
             yield separator()
 
     def filter(self, chunks):
+        discarded = 0
         for final, (index, item) in lookahead(enumerate(chunks)):
             item.temp = final, index
-            yield item
+            if not item.visible and self.isatty:
+                discarded += 1
+            else:
+                yield item
+        if discarded:
+            self.log_warn(F'discarded {discarded} invisible chunks to prevent them from leaking into the terminal.')
